/* dsp.h */

/***********************************************************************
*  This code is part of the RPS Drawing Subprogram Package.
*
*  Copyright (C) 2010, 2011, 2012 Andrew Makhorin, Department for
*  Applied Informatics, Moscow Aviation Institute, Moscow, Russia.
*  All rights reserved.  E-mail: <mao@gnu.org>.
*
*  This code is free software: you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published
*  by the Free Software Foundation, either version 3 of the License,
*  or (at your option) any later version.
*
*  This code is distributed in the hope that it will be useful, but
*  WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this code.  If not, see <http://www.gnu.org/licenses/>.
***********************************************************************/

#ifndef DSP_H
#define DSP_H

typedef struct IMAGE IMAGE;
/* raster image descriptor */

#define DSP_WIDTH_MAX 32760
/* maximal image width, pixels */

#define DSP_HEIGHT_MAX 32760
/* maximal image height, pixels */

#define DSP_RES_MIN 1.0
/* minimal image resolution, pixels per inch */

#define DSP_RES_MAX 32760.0
/* maximal image resolution, pixels per inch */

IMAGE *dsp_new_image(int width, int height, int depth);
/* allocate new raster image */

int dsp_get_width(IMAGE *img);
/* retrieve width of raster image */

int dsp_get_height(IMAGE *img);
/* retrieve height of raster image */

int dsp_get_depth(IMAGE *img);
/* retrieve color depth of raster image */

void dsp_set_res(IMAGE *img, double h_res, double v_res);
/* set resolution of raster image */

int dsp_get_rgb(IMAGE *img, int color);
/* retrieve RGB color assigned to specified color value */

void dsp_set_rgb(IMAGE *img, int color, int rgb);
/* assign specified color value given RGB color */

int dsp_get_color(IMAGE *img);
/* retrieve current color value */

void dsp_set_color(IMAGE *img, int color);
/* set current color value */

int dsp_get_pixel(IMAGE *img, int x, int y);
/* retrieve color value assigned to specified pixel */

int dsp_set_pixel(IMAGE *img, int x, int y);
/* assign current color value to specified pixel */

void dsp_free_image(IMAGE *img);
/* deallocate specified raster image */

void dsp_draw_h_line(IMAGE *img, int x1, int x2, int y);
/* draw "thin" horizontal line segment */

void dsp_draw_v_line(IMAGE *img, int x, int y1, int y2);
/* draw "thin" vertical line segment */

void dsp_draw_box(IMAGE *img, int fill, int x1, int y1, int x2,
      int y2);
/* draw rectangular box */

void dsp_draw_line(IMAGE *img, int x1, int y1, int x2, int y2);
/* draw "thin" line segment */

int dsp_set_charset(const char *name);
/* set character encoding */

int dsp_c2u(int c);
/* convert 8-bit character to 16-bit Unicode character */

int dsp_u2c(int u);
/* convert 16-bit Unicode character to 8-bit character */

void dsp_draw_char_u(IMAGE *img, int x, int y, int u);
/* draw specified 16-bit Unicode character */

void dsp_draw_char(IMAGE *img, int x, int y, int c);
/* draw specified 8-bit character */

int dsp_write_tiff(IMAGE *img, const char *name);
/* write raster image into TIFF file */

#endif

/* eof */
