/* f2c.h (Fortran-to-C header file for RPS) */

/* Modified by Andrew Makhorin <mao@gnu.org>, November 2012. */
/* For original code see <f2c-20100903/f2c.h>. */

#ifndef F2C_H
#define F2C_H

/* barf [ba:rf]  2.  "He suggested using FORTRAN, and everybody barfed."

   - From The Shogakukan DICTIONARY OF NEW ENGLISH (Second edition) */

typedef int integer;
typedef unsigned uinteger;
typedef char *address;
typedef short shortint;
typedef float real;
typedef double doublereal;
typedef struct { real r, i; } complex;
typedef struct { doublereal r, i; } doublecomplex;
typedef int logical;
typedef short shortlogical;
typedef char logical1;
typedef signed char integer1;

/* procedure parameter types for -A */

#define F2C_proc_par_types 1

#define VOID void

typedef int /* unknown procedure type */ (*U_fp)();
typedef shortint (*J_fp)();
typedef integer (*I_fp)();
typedef real (*R_fp)();
/* E_fp is for real functions when -R is not specified */
typedef doublereal (*D_fp)(), (*E_fp)();
typedef /* complex */ VOID (*C_fp)();
typedef /* double complex */ VOID (*Z_fp)();
typedef logical (*L_fp)();
typedef shortlogical (*K_fp)();
typedef /* character */ VOID (*H_fp)();
typedef /* subroutine */ int (*S_fp)();
typedef VOID C_f; /* complex function */
typedef VOID H_f; /* character function */
typedef VOID Z_f; /* double complex function */
typedef doublereal E_f; /* real function with -R not specified */

typedef union
{     /* for multiple entry points */
      integer1 g;
      shortint h;
      integer i;
      real r;
      doublereal d;
      complex c;
      doublecomplex z;
} Multitype;

/* Extern is for use with -E */
#ifndef Extern
#define Extern extern
#endif

#define TRUE_  1
#define FALSE_ 0

#undef abs
#undef min
#undef max

#define abs(x) ((x) >= 0 ? (x) : -(x))
#define dabs(x) ((doublereal)abs(x))
#define min(a, b) ((a) <= (b) ? (a) : (b))
#define max(a, b) ((a) >= (b) ? (a) : (b))
#define dmin(a, b) ((doublereal)min(a, b))
#define dmax(a, b) ((doublereal)max(a, b))
#define bit_test(a, b) (((a) >> (b)) & 1)
#define bit_clear(a, b) ((a) & ~((uinteger)1 << (b)))
#define bit_set(a, b) ((a) | ((uinteger)1 << (b)))

/* I/O stuff */

typedef int flag;
typedef int ftnlen;
typedef int ftnint;

typedef struct
{     /* external read, write */
      flag cierr;
      ftnint ciunit;
      flag ciend;
      char *cifmt;
      ftnint cirec;
} cilist;

typedef struct
{     /* internal read, write */
      flag icierr;
      char *iciunit;
      flag iciend;
      char *icifmt;
      ftnint icirlen;
      ftnint icirnum;
} icilist;

typedef struct
{     /* open */
      flag oerr;
      ftnint ounit;
      char *ofnm;
      ftnlen ofnmlen;
      char *osta;
      char *oacc;
      char *ofm;
      ftnint orl;
      char *oblnk;
} olist;

typedef struct
{     /* close */
      flag cerr;
      ftnint cunit;
      char *csta;
} cllist;

typedef struct
{     /* rewind, backspace, endfile */
      flag aerr;
      ftnint aunit;
} alist;

typedef struct
{     /* inquire (parameters in standard's order) */
      flag inerr;
      ftnint inunit;
      char *infile;
      ftnlen infilen;
      ftnint *inex;
      ftnint *inopen;
      ftnint *innum;
      ftnint *innamed;
      char *inname;
      ftnlen innamlen;
      char *inacc;
      ftnlen inacclen;
      char *inseq;
      ftnlen inseqlen;
      char *indir;
      ftnlen indirlen;
      char *infmt;
      ftnlen infmtlen;
      char *inform;
      ftnint informlen;
      char *inunf;
      ftnlen inunflen;
      ftnint *inrecl;
      ftnint *innrec;
      char *inblank;
      ftnlen inblanklen;
} inlist;

typedef struct
{     /* for Namelist */
      char *name;
      char *addr;
      ftnlen *dims;
      int type;
} Vardesc;

typedef struct
{     char *name;
      Vardesc **vars;
      int nvars;
} Namelist;

#endif

/* eof */
