/* stdio.h */

/***********************************************************************
*  Copyright (C) 2013 Andrew Makhorin <mao@gnu.org>.
*
*  This code is distributed under the terms of the GNU General Public
*  License, version 3 or later.
***********************************************************************/

#ifndef _STDIO_H
#define _STDIO_H

#ifndef _SIZE_T
#define _SIZE_T
typedef unsigned size_t;
#endif

typedef struct _IOBUF FILE;

typedef struct { long int _Pos; } fpos_t;

#define NULL ((void *)0)

#define _IOFBF 0x00
#define _IONBF 0x04
#define _IOLBF 0x40

#define BUFSIZ 512

#define EOF (-1)

#define FOPEN_MAX 32

#define FILENAME_MAX 256

#define L_tmpnam FILENAME_MAX

#define SEEK_SET 0
#define SEEK_CUR 1
#define SEEK_END 2

#define TMP_MAX 32760

#define stdin  ((FILE *)_Stdin)
#define stdout ((FILE *)_Stdout)
#define stderr ((FILE *)_Stderr)

extern FILE *_Stdin;
extern FILE *_Stdout;
extern FILE *_Stderr;

void clearerr(FILE *);
int fclose(FILE *);
int feof(FILE *);
int ferror(FILE *);
int fflush(FILE *);
int fgetc(FILE *);
int fgetpos(FILE *, fpos_t *);
char *fgets(char *, int, FILE *);
FILE *fopen(const char *, const char *);
int fprintf(FILE *, const char *, ...);
int fputc(int, FILE *);
int fputs(const char *, FILE *);
size_t fread(void *, size_t, size_t, FILE *);
FILE *freopen(const char *, const char *, FILE *);
int fscanf(FILE *, const char *, ...);
int fseek(FILE *, long int, int);
int fsetpos(FILE *, const fpos_t *);
long int ftell(FILE *);
size_t fwrite(const void *, size_t, size_t, FILE *);
int getc(FILE *);
int getchar(void);
char *gets(char *);
void perror(const char *);
int printf(const char *, ...);
int putc(int, FILE *);
int putchar(int);
int puts(const char *);
int remove(const char *);
int rename(const char *, const char *);
void rewind(FILE *);
int scanf(const char *, ...);
void setbuf(FILE *, char *);
int setvbuf(FILE *, char *, int, size_t);
int sprintf(char *, const char *, ...);
int sscanf(const char *, const char *, ...);
FILE *tmpfile(void);
char *tmpnam(char *);
int ungetc(int, FILE *);
int vfprintf(FILE *, const char *, __builtin_va_list);
int vprintf(const char *, __builtin_va_list);
int vsprintf(char *, const char *, __builtin_va_list);

#endif

/* eof */
